package ru.ulstu.strategy.api;

import org.springframework.stereotype.Service;
import ru.ulstu.core.util.DateUtils;
import ru.ulstu.paper.model.Paper;
import ru.ulstu.paper.service.PaperService;
import ru.ulstu.user.model.User;
import ru.ulstu.user.service.UserService;

import java.util.Date;
import java.util.List;

@Service
public class PaperCreateStrategy extends EntityCreateStrategy<Paper> {
    private static final String DEFAULT_NAME = "Статья создана автоматически";
    private static final int DEFAULT_DEADLINE_DAYS = 14;
    private final PaperService paperService;
    private final UserService userService;

    public PaperCreateStrategy(PaperService paperService,
                               UserService userService) {
        this.paperService = paperService;
        this.userService = userService;
    }

    @Override
    protected List<Paper> getActiveEntities() {
        return paperService.findAll();
    }

    @Override
    protected void createEntity(User user) {
        paperService.create(DEFAULT_NAME, user, DateUtils.addDays(new Date(), DEFAULT_DEADLINE_DAYS));
    }
}
